==> react-native-neurosdk2-1.0.24.tgz: package/android/src/main/java/com/neurosdk2/CallibriImpl.java <==
package com.neurosdk2;

import static com.neurosdk2.Utils.ConvertMEMSData;
import static com.neurosdk2.Utils.DATA_ID;
import static com.neurosdk2.Utils.GUID_ID;
import static com.neurosdk2.Utils.sendEvent;

import android.util.Log;

import com.facebook.react.bridge.Arguments;
import com.facebook.react.bridge.ReactApplicationContext;
import com.facebook.react.bridge.ReadableArray;
import com.facebook.react.bridge.ReadableMap;
import com.facebook.react.bridge.WritableArray;
import com.facebook.react.bridge.WritableMap;
import com.neurosdk2.neuro.BrainBit;
import com.neurosdk2.neuro.Callibri;
import com.neurosdk2.neuro.Sensor;
import com.neurosdk2.neuro.types.BrainBitSignalData;
import com.neurosdk2.neuro.types.CallibriEnvelopeData;
import com.neurosdk2.neuro.types.CallibriMotionAssistantParams;
import com.neurosdk2.neuro.types.CallibriMotionCounterParam;
import com.neurosdk2.neuro.types.CallibriRespirationData;
import com.neurosdk2.neuro.types.CallibriSignalData;
import com.neurosdk2.neuro.types.CallibriSignalType;
import com.neurosdk2.neuro.types.CallibriStimulationParams;
import com.neurosdk2.neuro.types.CallibriStimulatorMAState;
import com.neurosdk2.neuro.types.MEMSData;
import com.neurosdk2.neuro.types.QuaternionData;
import com.neurosdk2.neuro.types.SensorADCInput;
import com.neurosdk2.neuro.types.SensorAccelerometerSensitivity;
import com.neurosdk2.neuro.types.SensorDataOffset;
import com.neurosdk2.neuro.types.SensorExternalSwitchInput;
import com.neurosdk2.neuro.types.SensorFilter;
import com.neurosdk2.neuro.types.SensorFirmwareMode;
import com.neurosdk2.neuro.types.SensorGain;
import com.neurosdk2.neuro.types.SensorGyroscopeSensitivity;
import com.neurosdk2.neuro.types.SensorSamplingFrequency;

import java.util.ArrayList;
import java.util.List;

public class CallibriImpl extends AFullSensor{

  public CallibriImpl(Sensor sensor, String guid, ReactApplicationContext context){
    this.sensor = sensor;
    this.guid = guid;
    this.reactContext = context;
    addCallbacks();
  }

  @Override
  protected void addCallbacks() {
    super.addCallbacks();
    ((Callibri)sensor).callibriSignalDataReceived = (data)->{
      WritableMap result = Arguments.createMap();
      result.putString(GUID_ID, guid);
      WritableArray array = Arguments.createArray();
      for (CallibriSignalData signalData : data) {
        WritableMap map = Arguments.createMap();
        map.putInt("PackNum", signalData.getPackNum());
        map.putArray("Samples", Arguments.fromArray(signalData.getSamples()));
        array.pushMap(map);
      }
      result.putArray(DATA_ID, array);
      sendEvent(reactContext,Constants.CALLIBRI_SIGNAL_DATA_EVENT_NAME.raw(), result);
    };
    ((Callibri)sensor).callibriElectrodeStateChanged = data -> {
      WritableMap result = Arguments.createMap();
      result.putString(GUID_ID, guid);
      WritableMap map = Arguments.createMap();
      map.putInt("CallibriElectrodeState", data.index());
      result.putMap(DATA_ID, map);
      sendEvent(reactContext,Constants.CALLIBRI_ELECTRODE_STATE_EVENT_NAME.raw(), result);

    };
    ((Callibri)sensor).callibriEnvelopeDataReceived = data ->{
      WritableMap result = Arguments.createMap();
      result.putString(GUID_ID, guid);
      WritableArray array = Arguments.createArray();
      for (CallibriEnvelopeData envelopeData : data) {
        WritableMap map = Arguments.createMap();
        map.putInt("PackNum", envelopeData.getPackNum());
        map.putDouble("Sample", envelopeData.getSample());
        array.pushMap(map);
      }
      result.putArray(DATA_ID, array);
      sendEvent(reactContext,Constants.CALLIBRI_ENVELOPE_DATA_EVENT_NAME.raw(), result);
    };
    ((Callibri)sensor).callibriRespirationDataReceived = data ->{
      WritableMap result = Arguments.createMap();
      result.putString(GUID_ID, guid);
      WritableArray array = Arguments.createArray();
      for (CallibriRespirationData respirationData : data) {
        WritableMap map = Arguments.createMap();
        map.putInt("PackNum", respirationData.getPackNum());
        map.putArray("Samples", Arguments.fromArray(respirationData.getSamples()));
        array.pushMap(map);
      }
      result.putArray(DATA_ID, array);
      sendEvent(reactContext,Constants.CALLIBRI_RESPIRATION_DATA_EVENT_NAME.raw(), result);
    };
    ((Callibri)sensor).memsDataReceived = data ->{
      WritableMap result = Arguments.createMap();
      result.putString(GUID_ID, guid);
      WritableArray array = Arguments.createArray();
      for (MEMSData memsData : data) {
        WritableMap map = Arguments.createMap();
        ConvertMEMSData(memsData, map);
        array.pushMap(map);
      }
      result.putArray(DATA_ID, array);
      sendEvent(reactContext,Constants.MEMSDATA_CHANGED_EVENT_NAME.raw(), result);
    };
    ((Callibri)sensor).quaternionDataRecieved = data ->{
      WritableMap result = Arguments.createMap();
      result.putString(GUID_ID, guid);
      WritableArray array = Arguments.createArray();
      for (QuaternionData quaternionData : data) {
        WritableMap map = Arguments.createMap();
        map.putInt("PackNum", quaternionData.getPackNum());
        map.putDouble("W", quaternionData.getW());
        map.putDouble("X", quaternionData.getX());
        map.putDouble("Y", quaternionData.getY());
        map.putDouble("Z", quaternionData.getZ());
        array.pushMap(map);
      }
      result.putArray(DATA_ID, array);
      sendEvent(reactContext,Constants.QUATERNIONDATA_CHANGED_EVENT_NAME.raw(), result);
    };
  }

  @Override
  protected void removeCallbacks() {
    super.removeCallbacks();
    ((Callibri)sensor).callibriSignalDataReceived = null;
    ((Callibri)sensor).callibriElectrodeStateChanged = null;
    ((Callibri)sensor).callibriEnvelopeDataReceived = null;
    ((Callibri)sensor).callibriRespirationDataReceived = null;
    ((Callibri)sensor).memsDataReceived = null;
    ((Callibri)sensor).quaternionDataRecieved = null;
  }

  @Override
  protected String getSensorName() {
    return "Callibri";
  }

  @Override
  public int getSamplingFrequencyMEMS() throws Exception {
    return ((Callibri)sensor).getSamplingFrequencyMEMS().index();
  }

  @Override
  public boolean isSupportedFilter(int filter) throws Exception {
    return ((Callibri)sensor).isSupportedFilter(SensorFilter.indexOf(filter));
  }

  @Override
  public void getSupportedFilters(WritableArray filters) throws Exception {
    List<SensorFilter> filterList = ((Callibri) sensor).getSupportedFilters();
    for (SensorFilter filter : filterList) {
      filters.pushInt(filter.index());
    }
  }

  @Override
  public void getHardwareFilters(WritableArray filters) throws Exception {
    List<SensorFilter> filterList = ((Callibri) sensor).getHardwareFilters();
    for (SensorFilter filter : filterList) {
      filters.pushInt(filter.index());
    }
  }

  @Override
  public void setHardwareFilters(ReadableArray filters) throws Exception {
    List<SensorFilter> hardwareFiltersList = new ArrayList<>();
    for (int i = 0; i < filters.size(); i++)
    {
      hardwareFiltersList.add(SensorFilter.indexOf(filters.getInt(i)));
    }
    ((Callibri)sensor).setHardwareFilters(hardwareFiltersList);
  }

  @Override
  public void setFirmwareMode(int mode) throws Exception {
    ((Callibri)sensor).setFirmwareMode(SensorFirmwareMode.indexOf(mode));
  }

  @Override
  public void setSamplingFrequency(int sf) throws Exception {
    ((Callibri)sensor).setSamplingFrequency(SensorSamplingFrequency.indexOf(sf));
  }

  @Override
  public void setGain(int gain) throws Exception {
    ((Callibri)sensor).setGain(SensorGain.indexOf(gain));
  }

  @Override
  public void setDataOffset(int offset) throws Exception {
    ((Callibri)sensor).setDataOffset(SensorDataOffset.indexOf(offset));
  }

  @Override
  public int getExtSwInput() throws Exception {
    return ((Callibri)sensor).getExtSwInput().index();
  }

  @Override
  public void setExtSwInput(int extSwInp) throws Exception {
    ((Callibri)sensor).setExtSwInput(SensorExternalSwitchInput.indexOf(extSwInp));
  }

  @Override
  public int getADCInput() throws Exception {
    return ((Callibri)sensor).getADCInput().index();
  }

  @Override
  public void setADCInput(int adcInp) throws Exception {
    ((Callibri)sensor).setADCInput(SensorADCInput.indexOf(adcInp));
  }

  @Override
  public void getStimulatorMAState(WritableMap map) throws Exception {
    CallibriStimulatorMAState state = ((Callibri)sensor).getStimulatorMAState();
    map.putInt("MAState",state.getMAState().index());
    map.putInt("StimulatorState",state.getStimulatorState().index());
  }

  @Override
  public void getStimulatorParam(WritableMap map) throws Exception {
    CallibriStimulationParams param = ((Callibri)sensor).getStimulatorParam();
    map.putInt("Current",param.getCurrent());
    map.putInt("Frequency",param.getFrequency());
    map.putInt("PulseWidth",param.getPulseWidth());
    map.putInt("StimulusDuration",param.getStimulusDuration());
  }

  @Override
  public void setStimulatorParam(ReadableMap param) throws Exception {
    ((Callibri)sensor).setStimulatorParam(new CallibriStimulationParams(
      (byte)param.getInt("Current"),
      (short) param.getInt("PulseWidth"),
      (byte) param.getInt("Frequency"),
      (short)param.getInt("StimulusDuration")
    ));
  }

  @Override
  public void getMotionAssistantParam(WritableMap map) throws Exception {
    CallibriMotionAssistantParams param = ((Callibri)sensor).getMotionAssistantParam();
    map.putInt("GyroStart",param.getGyroStart());
    map.putInt("GyroStop",param.getGyroStop());
    map.putInt("Limb",param.getLimb().index());
    map.putInt("MinPauseMs",param.getMinPauseMs());
  }

  @Override
  public void setMotionAssistantParam(ReadableMap param) throws Exception {
    ((Callibri)sensor).setMotionAssistantParam(new CallibriMotionAssistantParams(
      (byte)param.getInt("GyroStart"),
      (byte)param.getInt("GyroStop"),
      param.getInt("Limb"),
      (byte)param.getInt("MinPauseMs")
    ));
  }

  @Override
  public void getMotionCounterParam(WritableMap map) throws Exception {
    CallibriMotionCounterParam param = ((Callibri)sensor).getMotionCounterParam();
    map.putInt("InsenseThresholdMG",param.getInsenseThresholdMG());
    map.putInt("InsenseThresholdSample",param.getInsenseThresholdSample());
  }

  @Override
  public void setMotionCounterParam(ReadableMap param) throws Exception {
    ((Callibri)sensor).setMotionCounterParam(new CallibriMotionCounterParam(
      (short)param.getInt("InsenseThresholdMG"),
      (short)param.getInt("InsenseThresholdSample")
    ));
  }

  @Override
  public int getMotionCounter() throws Exception {
    return ((Callibri)sensor).getMotionCounter();
  }

  @Override
  public int getColor() throws Exception {
    return ((Callibri)sensor).getColor().index();
  }

  @Override
  public boolean getMEMSCalibrateState() throws Exception {
    return ((Callibri)sensor).getMEMSCalibrateState();
  }

  @Override
  public int getSamplingFrequencyResp() throws Exception {
    return ((Callibri)sensor).getSamplingFrequencyResp().index();
  }

  @Override
  public int getSamplingFrequencyEnvelope() throws Exception {
    return ((Callibri)sensor).getSamplingFrequencyEnvelope().index();
  }

  @Override
  public int getSignalType() throws Exception {
    return ((Callibri)sensor).getSignalType().index();
  }

  @Override
  public void setSignalType(int type) throws Exception {
    ((Callibri)sensor).setSignalType(CallibriSignalType.indexOf(type));
  }

  @Override
  public int getElectrodeState() throws Exception {
    return ((Callibri)sensor).getElectrodeState().index();
  }

  @Override
  public int getAccSens() throws Exception {
    return ((Callibri)sensor).getAccSens().index();
  }

  @Override
  public void setAccSens(int accSens) throws Exception {
    ((Callibri)sensor).setAccSens(SensorAccelerometerSensitivity.indexOf(accSens));
  }

  @Override
  public int getGyroSens() throws Exception {
    return ((Callibri)sensor).getGyroSens().index();
  }

  @Override
  public void setGyroSens(int gyroSens) throws Exception {
    ((Callibri)sensor).setGyroSens(SensorGyroscopeSensitivity.indexOf(gyroSens));
  }
}

==> react-native-neurosdk2-1.0.27.tgz: package/android/src/main/java/com/neurosdk2/CallibriImpl.java <==
package com.neurosdk2;

import static com.neurosdk2.Utils.ConvertMEMSData;
import static com.neurosdk2.Utils.DATA_ID;
import static com.neurosdk2.Utils.GUID_ID;
import static com.neurosdk2.Utils.sendEvent;

import android.util.Log;

import com.facebook.react.bridge.Arguments;
import com.facebook.react.bridge.ReactApplicationContext;
import com.facebook.react.bridge.ReadableArray;
import com.facebook.react.bridge.ReadableMap;
import com.facebook.react.bridge.WritableArray;
import com.facebook.react.bridge.WritableMap;
import com.neurosdk2.neuro.BrainBit;
import com.neurosdk2.neuro.Callibri;
import com.neurosdk2.neuro.Sensor;
import com.neurosdk2.neuro.types.BrainBitSignalData;
import com.neurosdk2.neuro.types.CallibriEnvelopeData;
import com.neurosdk2.neuro.types.CallibriMotionAssistantParams;
import com.neurosdk2.neuro.types.CallibriMotionCounterParam;
import com.neurosdk2.neuro.types.CallibriRespirationData;
import com.neurosdk2.neuro.types.CallibriSignalData;
import com.neurosdk2.neuro.types.CallibriSignalType;
import com.neurosdk2.neuro.types.CallibriStimulationParams;
import com.neurosdk2.neuro.types.CallibriStimulatorMAState;
import com.neurosdk2.neuro.types.MEMSData;
import com.neurosdk2.neuro.types.QuaternionData;
import com.neurosdk2.neuro.types.SensorADCInput;
import com.neurosdk2.neuro.types.SensorAccelerometerSensitivity;
import com.neurosdk2.neuro.types.SensorDataOffset;
import com.neurosdk2.neuro.types.SensorExternalSwitchInput;
import com.neurosdk2.neuro.types.SensorFilter;
import com.neurosdk2.neuro.types.SensorFirmwareMode;
import com.neurosdk2.neuro.types.SensorGain;
import com.neurosdk2.neuro.types.SensorGyroscopeSensitivity;
import com.neurosdk2.neuro.types.SensorSamplingFrequency;
import com.facebook.react.bridge.CxxCallbackImpl;

import java.util.ArrayList;
import java.util.List;

public class CallibriImpl extends AFullSensor{

  public CallibriImpl(Sensor sensor, String guid, ReactApplicationContext context, CxxCallbackImpl sensorCallback){
    this.sensor = sensor;
    this.guid = guid;
    this.reactContext = context;
    this.cxxCallback = sensorCallback;
    addCallbacks();
  }

  @Override
  protected void addCallbacks() {
    super.addCallbacks();
    ((Callibri)sensor).callibriSignalDataReceived = (data)->{
      WritableMap result = Arguments.createMap();
      result.putString(GUID_ID, guid);
      WritableArray array = Arguments.createArray();
      for (CallibriSignalData signalData : data) {
        WritableMap map = Arguments.createMap();
        map.putInt("PackNum", signalData.getPackNum());
        map.putArray("Samples", Arguments.fromArray(signalData.getSamples()));
        array.pushMap(map);
      }
      result.putArray(DATA_ID, array);
      if(cxxCallback == null){
        sendEvent(reactContext,Constants.CALLIBRI_SIGNAL_DATA_EVENT_NAME.raw(), result);
      }
      else 
      {
        cxxCallback.invoke(Constants.CALLIBRI_SIGNAL_DATA_EVENT_NAME.raw(), result);
      }
    };
    ((Callibri)sensor).callibriElectrodeStateChanged = data -> {
      WritableMap result = Arguments.createMap();
      result.putString(GUID_ID, guid);
      WritableMap map = Arguments.createMap();
      map.putInt("CallibriElectrodeState", data.index());
      result.putMap(DATA_ID, map);
      if(cxxCallback == null){
        sendEvent(reactContext,Constants.CALLIBRI_ELECTRODE_STATE_EVENT_NAME.raw(), result);
      }
      else 
      {
        cxxCallback.invoke(Constants.CALLIBRI_ELECTRODE_STATE_EVENT_NAME.raw(), result);
      }
    };
    ((Callibri)sensor).callibriEnvelopeDataReceived = data ->{
      WritableMap result = Arguments.createMap();
      result.putString(GUID_ID, guid);
      WritableArray array = Arguments.createArray();
      for (CallibriEnvelopeData envelopeData : data) {
        WritableMap map = Arguments.createMap();
        map.putInt("PackNum", envelopeData.getPackNum());
        map.putDouble("Sample", envelopeData.getSample());
        array.pushMap(map);
      }
      result.putArray(DATA_ID, array);
      if(cxxCallback == null){
        sendEvent(reactContext,Constants.CALLIBRI_ENVELOPE_DATA_EVENT_NAME.raw(), result);
      }
      else 
      {
        cxxCallback.invoke(Constants.CALLIBRI_ENVELOPE_DATA_EVENT_NAME.raw(), result);
      }
    };
    ((Callibri)sensor).callibriRespirationDataReceived = data ->{
      WritableMap result = Arguments.createMap();
      result.putString(GUID_ID, guid);
      WritableArray array = Arguments.createArray();
      for (CallibriRespirationData respirationData : data) {
        WritableMap map = Arguments.createMap();
        map.putInt("PackNum", respirationData.getPackNum());
        map.putArray("Samples", Arguments.fromArray(respirationData.getSamples()));
        array.pushMap(map);
      }
      result.putArray(DATA_ID, array);
      if(cxxCallback == null){
        sendEvent(reactContext,Constants.CALLIBRI_RESPIRATION_DATA_EVENT_NAME.raw(), result);
      }
      else 
      {
        cxxCallback.invoke(Constants.CALLIBRI_RESPIRATION_DATA_EVENT_NAME.raw(), result);
      }
    };
    ((Callibri)sensor).memsDataReceived = data ->{
      WritableMap result = Arguments.createMap();
      result.putString(GUID_ID, guid);
      WritableArray array = Arguments.createArray();
      for (MEMSData memsData : data) {
        WritableMap map = Arguments.createMap();
        ConvertMEMSData(memsData, map);
        array.pushMap(map);
      }
      result.putArray(DATA_ID, array);
      if(cxxCallback == null){
        sendEvent(reactContext,Constants.MEMSDATA_CHANGED_EVENT_NAME.raw(), result);
      }
      else 
      {
        cxxCallback.invoke(Constants.MEMSDATA_CHANGED_EVENT_NAME.raw(), result);
      }
    };
    ((Callibri)sensor).quaternionDataRecieved = data ->{
      WritableMap result = Arguments.createMap();
      result.putString(GUID_ID, guid);
      WritableArray array = Arguments.createArray();
      for (QuaternionData quaternionData : data) {
        WritableMap map = Arguments.createMap();
        map.putInt("PackNum", quaternionData.getPackNum());
        map.putDouble("W", quaternionData.getW());
        map.putDouble("X", quaternionData.getX());
        map.putDouble("Y", quaternionData.getY());
        map.putDouble("Z", quaternionData.getZ());
        array.pushMap(map);
      }
      result.putArray(DATA_ID, array);
      if(cxxCallback == null){
        sendEvent(reactContext,Constants.QUATERNIONDATA_CHANGED_EVENT_NAME.raw(), result);
      }
      else 
      {
        cxxCallback.invoke(Constants.QUATERNIONDATA_CHANGED_EVENT_NAME.raw(), result);
      }
    };
  }

  @Override
  protected void removeCallbacks() {
    super.removeCallbacks();
    ((Callibri)sensor).callibriSignalDataReceived = null;
    ((Callibri)sensor).callibriElectrodeStateChanged = null;
    ((Callibri)sensor).callibriEnvelopeDataReceived = null;
    ((Callibri)sensor).callibriRespirationDataReceived = null;
    ((Callibri)sensor).memsDataReceived = null;
    ((Callibri)sensor).quaternionDataRecieved = null;
  }

  @Override
  protected String getSensorName() {
    return "Callibri";
  }

  @Override
  public int getSamplingFrequencyMEMS() throws Exception {
    return ((Callibri)sensor).getSamplingFrequencyMEMS().index();
  }

  @Override
  public boolean isSupportedFilter(int filter) throws Exception {
    return ((Callibri)sensor).isSupportedFilter(SensorFilter.indexOf(filter));
  }

  @Override
  public void getSupportedFilters(WritableArray filters) throws Exception {
    List<SensorFilter> filterList = ((Callibri) sensor).getSupportedFilters();
    for (SensorFilter filter : filterList) {
      filters.pushInt(filter.index());
    }
  }

  @Override
  public void getHardwareFilters(WritableArray filters) throws Exception {
    List<SensorFilter> filterList = ((Callibri) sensor).getHardwareFilters();
    for (SensorFilter filter : filterList) {
      filters.pushInt(filter.index());
    }
  }

  @Override
  public void setHardwareFilters(ReadableArray filters) throws Exception {
    List<SensorFilter> hardwareFiltersList = new ArrayList<>();
    for (int i = 0; i < filters.size(); i++)
    {
      hardwareFiltersList.add(SensorFilter.indexOf(filters.getInt(i)));
    }
    ((Callibri)sensor).setHardwareFilters(hardwareFiltersList);
  }

  @Override
  public void setFirmwareMode(int mode) throws Exception {
    ((Callibri)sensor).setFirmwareMode(SensorFirmwareMode.indexOf(mode));
  }

  @Override
  public void setSamplingFrequency(int sf) throws Exception {
    ((Callibri)sensor).setSamplingFrequency(SensorSamplingFrequency.indexOf(sf));
  }

  @Override
  public void setGain(int gain) throws Exception {
    ((Callibri)sensor).setGain(SensorGain.indexOf(gain));
  }

  @Override
  public void setDataOffset(int offset) throws Exception {
    ((Callibri)sensor).setDataOffset(SensorDataOffset.indexOf(offset));
  }

  @Override
  public int getExtSwInput() throws Exception {
    return ((Callibri)sensor).getExtSwInput().index();
  }

  @Override
  public void setExtSwInput(int extSwInp) throws Exception {
    ((Callibri)sensor).setExtSwInput(SensorExternalSwitchInput.indexOf(extSwInp));
  }

  @Override
  public int getADCInput() throws Exception {
    return ((Callibri)sensor).getADCInput().index();
  }

  @Override
  public void setADCInput(int adcInp) throws Exception {
    ((Callibri)sensor).setADCInput(SensorADCInput.indexOf(adcInp));
  }

  @Override
  public void getStimulatorMAState(WritableMap map) throws Exception {
    CallibriStimulatorMAState state = ((Callibri)sensor).getStimulatorMAState();
    map.putInt("MAState",state.getMAState().index());
    map.putInt("StimulatorState",state.getStimulatorState().index());
  }

  @Override
  public void getStimulatorParam(WritableMap map) throws Exception {
    CallibriStimulationParams param = ((Callibri)sensor).getStimulatorParam();
    map.putInt("Current",param.getCurrent());
    map.putInt("Frequency",param.getFrequency());
    map.putInt("PulseWidth",param.getPulseWidth());
    map.putInt("StimulusDuration",param.getStimulusDuration());
  }

  @Override
  public void setStimulatorParam(ReadableMap param) throws Exception {
    ((Callibri)sensor).setStimulatorParam(new CallibriStimulationParams(
      (byte)param.getInt("Current"),
      (short) param.getInt("PulseWidth"),
      (byte) param.getInt("Frequency"),
      (short)param.getInt("StimulusDuration")
    ));
  }

  @Override
  public void getMotionAssistantParam(WritableMap map) throws Exception {
    CallibriMotionAssistantParams param = ((Callibri)sensor).getMotionAssistantParam();
    map.putInt("GyroStart",param.getGyroStart());
    map.putInt("GyroStop",param.getGyroStop());
    map.putInt("Limb",param.getLimb().index());
    map.putInt("MinPauseMs",param.getMinPauseMs());
  }

  @Override
  public void setMotionAssistantParam(ReadableMap param) throws Exception {
    ((Callibri)sensor).setMotionAssistantParam(new CallibriMotionAssistantParams(
      (byte)param.getInt("GyroStart"),
      (byte)param.getInt("GyroStop"),
      param.getInt("Limb"),
      (byte)param.getInt("MinPauseMs")
    ));
  }

  @Override
  public void getMotionCounterParam(WritableMap map) throws Exception {
    CallibriMotionCounterParam param = ((Callibri)sensor).getMotionCounterParam();
    map.putInt("InsenseThresholdMG",param.getInsenseThresholdMG());
    map.putInt("InsenseThresholdSample",param.getInsenseThresholdSample());
  }

  @Override
  public void setMotionCounterParam(ReadableMap param) throws Exception {
    ((Callibri)sensor).setMotionCounterParam(new CallibriMotionCounterParam(
      (short)param.getInt("InsenseThresholdMG"),
      (short)param.getInt("InsenseThresholdSample")
    ));
  }

  @Override
  public int getMotionCounter() throws Exception {
    return ((Callibri)sensor).getMotionCounter();
  }

  @Override
  public int getColor() throws Exception {
    return ((Callibri)sensor).getColor().index();
  }

  @Override
  public boolean getMEMSCalibrateState() throws Exception {
    return ((Callibri)sensor).getMEMSCalibrateState();
  }

  @Override
  public int getSamplingFrequencyResp() throws Exception {
    return ((Callibri)sensor).getSamplingFrequencyResp().index();
  }

  @Override
  public int getSamplingFrequencyEnvelope() throws Exception {
    return ((Callibri)sensor).getSamplingFrequencyEnvelope().index();
  }

  @Override
  public int getSignalType() throws Exception {
    return ((Callibri)sensor).getSignalType().index();
  }

  @Override
  public void setSignalType(int type) throws Exception {
    ((Callibri)sensor).setSignalType(CallibriSignalType.indexOf(type));
  }

  @Override
  public int getElectrodeState() throws Exception {
    return ((Callibri)sensor).getElectrodeState().index();
  }

  @Override
  public int getAccSens() throws Exception {
    return ((Callibri)sensor).getAccSens().index();
  }

  @Override
  public void setAccSens(int accSens) throws Exception {
    ((Callibri)sensor).setAccSens(SensorAccelerometerSensitivity.indexOf(accSens));
  }

  @Override
  public int getGyroSens() throws Exception {
    return ((Callibri)sensor).getGyroSens().index();
  }

  @Override
  public void setGyroSens(int gyroSens) throws Exception {
    ((Callibri)sensor).setGyroSens(SensorGyroscopeSensitivity.indexOf(gyroSens));
  }
}
